JSHint, A Static Code Analysis Tool for JavaScript
--------------------------------------------------

\[ [Use it online](http://jshint.com/) •  [About](http://jshint.com/about/) • 
[Docs](http://jshint.com/docs/) • [FAQ](http://jshint.com/docs/faq) • 
[Install](http://jshint.com/install/) • [Hack](http://jshint.com/hack/) • 
[Blog](http://jshint.com/blog/) • [Twitter](https://twitter.com/jshint/) \]

[![Build Status](https://travis-ci.org/jshint/jshint.png?branch=master)](https://travis-ci.org/jshint/jshint)
[![NPM version](https://badge.fury.io/js/jshint.png)](http://badge.fury.io/js/jshint)

JSHint is a community-driven tool to detect errors and potential problems
in JavaScript code and to enforce your team’s coding conventions. It is
very flexible so you can easily adjust it to your particular coding guidelines
and the environment you expect your code to execute in.

#### JSHint 2.x versus JSHint 3

There's an effort going on to release the next major version of JSHint. All
development in the `master` branch is for the version 3.0. Current stable
version is in the `2.x` branch. Keep that in mind when submitting pull requests.

Also, before reporting a bug or thinking about hacking on JSHint, read this:
[JSHint 3 plans](http://www.jshint.com/blog/jshint-3-plans/). TL;DR: we're
moving away from style checks within JSHint so no new features around
style checks will be accepted. Bug fixes are fine for the `2.x` branch.

#### Reporting a bug

To report a bug simply create a
[new GitHub Issue](https://github.com/jshint/jshint/issues/new) and describe
your problem or suggestion. We welcome all kind of feedback regarding
JSHint including but not limited to:

 * When JSHint doesn't work as expected
 * When JSHint complains about valid JavaScript code that works in all browsers
 * When you simply want a new option or feature

Before reporting a bug look around to see if there are any open or closed tickets
that cover your issue. And remember the wisdom: pull request > bug report > tweet.


#### License

JSHint is distributed under the MIT License. One file and one file only
(src/stable/jshint.js) is distributed under the slightly modified MIT License.


#### Thank you!

We really appreciate all kind of feedback and contributions. Thanks for using and supporting JSHint!
